/*   --------------------------------------------------------------------  *
 *   CT Cron Header                                                        *
 *   --------------------------------------------------------------------  *
 *   Copyright (C) 1999, Gary Meyer <gary@meyer.net>                       *
 *   --------------------------------------------------------------------  *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 ***************************************************************************/

#ifndef CTCRON_H
#define CTCRON_H

// Do not introduce any Qt or KDE dependencies into the "CT"-prefixed classes.
// I want to be able to reuse these classes with another GUI toolkit. -GM 11/99

#include <string>
#include <iostream>
#include <qstring.h>
#include <qstringlist.h>
#include "cttask.h"
#include "ctvariable.h"
#include "rffile.h"
class CTException;

/**
  * A user (encapsulation of a single crontab file).  Encapsulates
  * file i/o, parsing, tokenization, and natural language description.
  */
class CTCron
{
public:

  CTCron(bool _syscron = false, QString _login = "");


  void add(const QString& _command,const QString& _comment);
  void edit(const QString& _command,const QString& _comment,int _first,int _last,bool _enable);
  void  del(int _first,int _last);
  void del_variable(int line);
  void edit_variable(int line,QString& buf);
  void add_variable(QString& buf);
/**
  * Indicates whether or not the crontab belongs to the system.
  */
  const bool syscron;

/**
  * User  login.
  */
  QString login;

/**
  * User real name.
  */
  QString name;
/*
 *  read /tmp/rf*
 * */
 void  read_file();
/**
  * User's scheduled tasks.
  */
  QPtrList<CTTask> task;

/**
  * User's environment variables.
  */
   QPtrList<CTVariable>  variable;
/**
  * Destructor.
  */
  ~CTCron();

  RFFile *fd;
  bool isDirty();
private:
  unsigned int initialTaskCount;
  unsigned int initialVariableCount;
  QString       writeCommand;
  QString       readCommand;
  QString       tmpFileName;
};


#endif // CTCRON_H
