/***************************************************************************
 *   ctunit.h                                                              *
 *   --------------------------------------------------------------------  *
 *   CT Unit of Time Interval Header                                       *
 *   --------------------------------------------------------------------  *
 *   Copyright (C) 1999, Gary Meyer <gary@meyer.net>                       *
 *   --------------------------------------------------------------------  *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 ***************************************************************************/
#ifndef CTUNIT_H
#define CTUNIT_H
#include <string>
#include <iostream>
#include <qstring.h>
/**
  * A cron table unit parser and tokenizer.
  * Parses/tokenizes unit such as "0-3,5,6,10-30/5"
  * Also provides default natural language description.
  */
template<int min, int max>
class CTUnit
{
public:

	/**
	 *   * Constant indicating short format.
	 *     */
 static const bool shortFormat = 0;

	  /**
	   *   * Constant indicating long format.
	   *     */
 static const bool longFormat = 1;
/**
  * Initialize including parsing and saving initial image.
  */
  CTUnit(const std::string &tokStr = "");

/**
  * Base initial image as empty and copy enabled intervals.
  */
  CTUnit(const CTUnit& source);

/**
  * Destructor.
  */
  virtual ~CTUnit();
/**
 *   range out
*/
  bool range_out;
  
/**
  * Parses unit such as "0-3,5,6,10-30/5".
  * And initialize array of enabled intervals.
  */
  void initialize(const std::string &tokStr = "");

/**
  * Parses unit such as "0-3,5,6,10-30/5".
  * Does not initialize array of enabled intervals.
  */
  void parse(std::string tokStr = "");
  
/**
  * Tokenizes unit into string such as
  * "0,1,2,3,5,6,10,15,20,25,30".
  */
  QString tokenize() const;

/**
  * Get default natural language description.
  */
  virtual std::string describe(const std::string *label) const;



/**
  * Total count of enabled intervals.
  */
  int count() const;
/**
 *   * Accessor.
 *     */
   bool get(int pos) const;

  /**
   *   * Mutator.
   *     */
    void set(int pos, bool value);

private:

  int fieldToValue(std::string entry) const;
  bool enabled[max+1];

};

//#include "ctunit.cpp"

#endif //CTUNIT_H
